@@ -7,7 +7,7 @@ Graphics::Primitive - Device and library agnostic graphic primitives
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 __PACKAGE__->meta->make_immutable;
 
@@ -73,6 +73,15 @@ to do their internal housekeeping to prepare for eventual drawing.  The
 lifecycle is: B<prepare>, B<layout> and B<pack>.  Detailed explanation of
 these methods can be found in L<Component|Graphics::Primitive::Component>.
 
+=head1 PREPARATION
+
+Graphics::Primitive::Component has a C<prepared> flag.  This flag is set as
+part of the C<prepare> method (shocking, I know).  If this flag is set, then
+subsequent calls to C<prepare> are ignored.  Containers also have a prepare
+flag, but this flag is B<not> set when calling C<prepare>.  A Contianer's flag
+should be set by the layout manager.  More information may be found with
+L<Layout::Manager>.
+
 =head1 INSPIRATION
 
 Most of the concepts that you'll find in Graphics::Primitive are inspired by
